/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GetReportsObjectsCommand.as 19356 2010-03-04 21:02:36Z mancelin $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.auditconsole.command {
import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;

import mx.collections.ArrayCollection;
import mx.controls.Alert;
import mx.rpc.IResponder;
import mx.rpc.events.FaultEvent;
import mx.rpc.events.ResultEvent;

import org.ow2.jasmine.kerneos.common.event.KerneosNotificationEvent;
import org.ow2.jasmine.kerneos.common.event.ServerSideExceptionEvent;
import org.ow2.jasmine.kerneos.common.view.ServerSideException;
import org.ow2.jonas.admin.auditconsole.business.IAuditConsoleDelegate;
import org.ow2.jonas.admin.auditconsole.model.AuditConsoleModelLocator;
import com.adobe.cairngorm.control.CairngormEventDispatcher;

import org.ow2.jonas.admin.auditconsole.model.TopsAuditModel;
import org.ow2.jonas.admin.auditconsole.util.IconsUtils;
import org.ow2.jonas.admin.auditconsole.vo.GenericAuditReportVO;
import org.ow2.jonas.admin.auditconsole.vo.InvocationAuditReportVO;
import org.ow2.jonas.admin.auditconsole.vo.JNDIAuditReportVO;
import org.ow2.jonas.admin.auditconsole.vo.ServerHealthVO;
import org.ow2.jonas.admin.auditconsole.vo.TopMethodVO;
import org.ow2.jonas.admin.auditconsole.vo.WebInvocationAuditReportVO;

/**
 * Command that call Java side methods.
 */
public class GetServerHealthCommand implements ICommand, IResponder {
    /**
    * Send the event to the java side, using the business layer of the pattern
    */
    public function execute( event:CairngormEvent ):void {
        var delegate:IAuditConsoleDelegate = AuditConsoleModelLocator.getInstance().getModuleDelegate()
        delegate.responder = this;
        delegate.getServerHealth();
    }
   /**
    * Get the result of the java side. this method is called on each event from
    * Java.
    */
    public function result( event : Object ):void {
        var model:AuditConsoleModelLocator = AuditConsoleModelLocator.getInstance();
        var health:ServerHealthVO = (event as ResultEvent).result as ServerHealthVO;
        if (health != null) {

            var icons:IconsUtils = IconsUtils.getInstance();

            model.stats.jonasReqAverage = health.globalMeanTime.toFixed(3) + " ms.";
            model.stats.jonasReqAverageTrend = icons.trendIcon(health.globalTrend);
            model.stats.jonasTotalReq = health.gobalTotalTime.toFixed(3) + " ms.";
            model.stats.jonasTotalReqTrend = icons.trendIcon(health.globalDurationTrend);
            model.stats.jonasReqCount = health.globalCounter + " times.";

            model.stats.easybeansReqAverage = health.ejbMeanTime.toFixed(3) + " ms.";
            model.stats.easybeansReqAverageTrend = icons.trendIcon(health.EJBTrend);
            model.stats.easybeansTotalReq = health.ejbTotalTime.toFixed(3) + " ms.";
            model.stats.easybeansTotalReqTrend = icons.trendIcon(health.EJBDurationTrend);
            model.stats.easybeansReqCount = health.ejbCounter  + "times.";

            model.stats.tomcatReqAverage = health.webMeanTime.toFixed(3) + " ms.";
            model.stats.tomcatReqAverageTrend = icons.trendIcon(health.WEBTrend);
            model.stats.tomcatTotalReq = health.webTotalTime.toFixed(3) + " ms.";
            model.stats.tomcatTotalReqTrend = icons.trendIcon(health.WEBDurationTrend);
            model.stats.tomcatReqCount = health.webCounter + "  times.";

            model.stats.jndiReqAverage = health.jndiMeanTime.toFixed(3) + " ms.";
            model.stats.jndiReqAverageTrend = icons.trendIcon(health.JNDITrend);
            model.stats.jndiTotalReq = health.jndiTotalTime.toFixed(3) + " ms.";
            model.stats.jndiTotalReqTrend = icons.trendIcon(health.JNDIDurationTrend);
            model.stats.jndiReqCount = health.jndiCounter + " times.";

            model.stats.updateTable();
        }
    }
    /**
    * Handle fault messages
    */
     public function fault( info : Object ) : void {
        //Alert.show("Error: "+info);
        var faultEvent : FaultEvent = FaultEvent(info);
        var serverSideExceptionEvent : ServerSideExceptionEvent =
            new ServerSideExceptionEvent(
                "serverSideException",
                new ServerSideException("Error while Executing the action",
                                        "The operation could not be performed."
                                        + "\n" + faultEvent.fault.faultCode
                                        + "\n" + faultEvent.fault.faultString,
                                        faultEvent.fault.getStackTrace()));
        CairngormEventDispatcher.getInstance().dispatchEvent(serverSideExceptionEvent);
    }

}
}
