/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IconsUtils.as 19387 2010-03-09 10:31:40Z mancelin $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.auditconsole.util {

/**
 * Utility class for icons.
 */
public class IconsUtils {

    private static var model:IconsUtils = null;

    // Tree & Report icons
    // ----------------------------
    [Embed("/../assets/tomcat.png")]
    public const tomcatIcon:Class;

    [Embed("/../assets/jndi.png")]
    public const jndiIcon:Class;

    [Embed("/../assets/jaxws.png")]
    public const jaxwsIcon:Class;

    [Embed("/../assets/bean.png")]
    public const beanIcon:Class;

    [Embed("/../assets/jonas.png")]
    public const jonasIcon:Class;

    [Embed("/../assets/method.png")]
    public const methodIcon:Class;

    // Trends icons
    // ---------------------------
    [Embed("/../assets/trends/up.png")]
    private const up:Class;

    [Embed("/../assets/trends/down.png")]
    private const down:Class;

    [Embed("/../assets/trends/equal.png")]
    private const equal:Class;


    /**
     * Constructor.
     */
    public function IconsUtils() { }

    public static function getInstance():IconsUtils {
        if (IconsUtils.model == null) {
            IconsUtils.model = new IconsUtils();
        }
        return IconsUtils.model;
    }

    /**
     * Get the icon for the tree node.
     * @param type type of the node.
     */
    public function treeIcon(type:String):Class {

        switch (type) {
            case "EJB":
                return beanIcon;
            case "HTTP":
                return tomcatIcon;
            case "JNDI":
                return jndiIcon;
            case "JAXWS":
                return jaxwsIcon;
            default:
                return jonasIcon;
        }

    }

    /**
     * Get the icon for a given trend.
     * @param value trend (up/down/equal).
     */
    public function trendIcon(value:String):Class {

        switch (value) {
            case "up":
                return up;
            case "down":
                return down;
            default:
                return equal;
        }
    }

    /**
     * Get the icon for a report.
     * @param type type of the node.
     */
    public function reportIcon(type:String):Class {

        switch (type) {
            case "EJB":
                return methodIcon;
            case "WEB":
                return tomcatIcon;
            case "JNDI":
                return jndiIcon;
            case "Jaxws":
                return jaxwsIcon;
            case "LIFECYCLE":
                return beanIcon;
            default:
                return jonasIcon;
        }

    }

}
}