/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AuditConsoleTreeBranchVO.as 19356 2010-03-04 21:02:36Z mancelin $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.auditconsole.view.tree {

import mx.collections.ArrayCollection;
import mx.controls.Alert;

/**
 * Generic tree branch.
 */
public class AbstractTreeBranch {

    private var _type:String;
    private var _label:String = "";
    private var _target:String = "";

    private var _node:XML = null;

    private var branchBeansAtt:ArrayCollection = new ArrayCollection();
    /**
     * Constructor.
     */
    public function AbstractTreeBranch(label:String, type:String, target:String) {

        // Store default label, target and type
        _label = label;
        _target = target;
        _type = type;

        // Create the root node of this branch
        _node = <node label={label}
                      type={type}
                      target={target} />;
    }

    public function get type():String {
        return _type;
    }

    public function get node():XML {
        return _node;
    }

    protected function mergeBranches(added:String):void {
        var exists:Boolean = false;
        var beansNames:Array = added.split("/");
        var tmpBranchAtt:XML = this._node;
        var path:String = _target + "/";
        if (beansNames.length > 0) {
            for (var i:int = 0; i < beansNames.length; i ++) {
                path = path.concat(beansNames[i]);
                if (beansNames[i] != "") {
                    for each(var node:XML in tmpBranchAtt.children()) {
                        if (node.@label == beansNames[i]) {
                            exists = true;
                            tmpBranchAtt = node;
                            break;
                        }
                    }
                    if (!exists) {
                        var newChild:XML = <node label={beansNames[i]}
                                                 type={type}
                                                 target={path} />;
                        tmpBranchAtt.appendChild(newChild);
                        tmpBranchAtt = newChild;
                    }
                    exists = false;
                    path = path.concat("/");
                }
            }
        }
    }

    public function addBean(bean:String):void {
        if (!branchBeansAtt.contains(bean)) {
            branchBeansAtt.addItem(bean);
            mergeBranches(bean);
        }
    }
}
}